# Project description

A Python library for Stripe’s API.

## Setup

You can install this package by using the pip tool and installing:

    $ pip install ragtastic

Or:

    $ uv add ragtastic

## Setting up a Ragtastic Account

Sign up for Ragtastic at https://useragtastic.com/register

## Using the Ragtastic API

Documentation for the python bindings can be found alongside Ragtastic’s other bindings here:

    https://useragtastic.com/docs